WavFileSink

Struct WavFileSink 

pub struct WavFileSink { /* private fields */ }
WAV file sink that writes audio incrementally.

Writes the WAV header on the first write_chunk call with a placeholder data size, then appends sample data on each chunk. On finalize, seeks back to update the RIFF file size and data chunk size fields.

Implementations

Source

impl WavFileSink

pub fn new(path: &Path) -> Result<Self, PiperError>

Create a new WAV file sink.

The file is created immediately but the WAV header is written on the first call to write_chunk (so that we know the sample rate).